Changelog
=========

1.0.2 (2017-12-21)
------------------

- Fix issue where default configuration directive being mutable caused
  unexpected behavior
  [datakurre]

1.0.1 (2016-09-21)
------------------

- Fix issue where zope.deferredimported module was not recognized as module
  [datakurre]

1.0.0 (2016-04-19)
------------------

- First release.
